#
# Configuration file for using the XML library in GNOME applications
#
XML2_LIBDIR="-L/var/folders/sy/f16zz6x50xz3113nwtb9bvq00000gp/T/abs_96213164-85b0-4fdd-bb61-a3d41cc6021bc6a0q829/croots/recipe/libxml2_1653546366102/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib"
XML2_LIBS="-lxml2 -L/var/folders/sy/f16zz6x50xz3113nwtb9bvq00000gp/T/abs_96213164-85b0-4fdd-bb61-a3d41cc6021bc6a0q829/croots/recipe/libxml2_1653546366102/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib -lz -L/var/folders/sy/f16zz6x50xz3113nwtb9bvq00000gp/T/abs_96213164-85b0-4fdd-bb61-a3d41cc6021bc6a0q829/croots/recipe/libxml2_1653546366102/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib -llzma -lpthread -L/var/folders/sy/f16zz6x50xz3113nwtb9bvq00000gp/T/abs_96213164-85b0-4fdd-bb61-a3d41cc6021bc6a0q829/croots/recipe/libxml2_1653546366102/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib -liconv -L/var/folders/sy/f16zz6x50xz3113nwtb9bvq00000gp/T/abs_96213164-85b0-4fdd-bb61-a3d41cc6021bc6a0q829/croots/recipe/libxml2_1653546366102/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/lib -licui18n -licuuc -licudata -lm "
XML2_INCLUDEDIR="-I/var/folders/sy/f16zz6x50xz3113nwtb9bvq00000gp/T/abs_96213164-85b0-4fdd-bb61-a3d41cc6021bc6a0q829/croots/recipe/libxml2_1653546366102/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/include/libxml2 -I/var/folders/sy/f16zz6x50xz3113nwtb9bvq00000gp/T/abs_96213164-85b0-4fdd-bb61-a3d41cc6021bc6a0q829/croots/recipe/libxml2_1653546366102/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_plac/include"
MODULE_VERSION="xml2-2.9.14"

